retrieve_insecure

Function retrieve_insecure 

pub fn retrieve_insecure<X, Z, A>(attr: A) -> InsecurePath<X, Z, A, Identity>
where A: InsecureAttr<X>,
retrieve_insecure is the starting point of a path that is not always present. For that reason, it returns a Result indicating the success of the path operation.